/*
 *	aegis - project change supervisor
 *	Copyright (C) 1999 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: interface definition for libaegis/output/private.c
 */

#ifndef LIBAEGIS_OUTPUT_PRIVATE_H
#define LIBAEGIS_OUTPUT_PRIVATE_H

#include <output.h>

output_ty *output_new _((output_vtbl_ty *));
long output_generic_ftell _((output_ty *));
void output_generic_fputs _((output_ty *, const char *));
void output_generic_write _((output_ty *, const void *, size_t));

#endif /* LIBAEGIS_OUTPUT_PRIVATE_H */
